@@ -1,6 +1,13 @@
+import tempfile
+import zipfile
 import pytest
 
-from onfido import TimelineFileReference, WorkflowRun, WorkflowRunBuilder, WorkflowRunStatus
+from onfido import (
+    TimelineFileReference,
+    WorkflowRun,
+    WorkflowRunBuilder,
+    WorkflowRunStatus,
+)
 from tests.conftest import (
     create_applicant,
     create_workflow_run,
@@ -70,6 +77,25 @@ def test_download_evidence_file(onfido_api, workflow_run):
     assert file[:4] == b"%PDF"
 
 
+def test_download_evidence_folder(onfido_api, applicant_id):
+    workflow_id = "221f9d24-cf72-4762-ac4a-01bf3ccc09dd"
+    workflow_run_id = create_workflow_run(
+        onfido_api, applicant_id=applicant_id, workflow_id=workflow_id
+    ).id
+    repeat_request_until_status_changes(
+        onfido_api.find_workflow_run, [workflow_run_id], WorkflowRunStatus.APPROVED
+    )
+
+    file = repeat_request_until_http_code_changes(
+        onfido_api.download_evidence_folder, [workflow_run_id]
+    )
+
+    assert len(file) > 0
+    with tempfile.NamedTemporaryFile() as tmp_file:
+        tmp_file.write(file)
+        assert zipfile.is_zipfile(tmp_file.name)
+
+
 def test_generate_timeline_file(onfido_api, applicant_id):
     workflow_id = "221f9d24-cf72-4762-ac4a-01bf3ccc09dd"
     workflow_run_id = create_workflow_run(
